#### Paper title: Polls of fear? Electoral violence, incumbent strength, and voter turnout in Côte d'Ivoire
#### Purpose: Data management, descriptive statistics, main analysis, appendix analysis
#### Author: Sebastian van Baalen
#### Date: 2023-01-04

#### Read this first ####

# If the script contains errors or fails to run, compare the package version
# with the version listed in the run-file.

# Note that starting from section "Additional analyses and robustness tests",
# the script overwrites existing model objects for convenience.

# The following error message when calculating McFadden's Adjusted R2 is due to
# the error message prompted by using glm with family = binomial(link = logit)
# and disappears if using glm with family = quasibinomial instead. The results
# are however the same.

  # Warning messages:
  #   1: In eval(family$initialize) : non-integer #successes in a binomial glm!
  #   2: In res["Tjur"] <- unname(diff(tapply(y.hat.resp, y, mean, na.rm = TRUE))) :
  #   number of items to replace is not a multiple of replacement length

#### Front matter ####

# Install packages

# Un-comment to install packages

#install.packages("here") # For using relative paths
#install.packages("ggplot2") # For making graphs and figures
#install.packages("tidyverse") # For working with tidy data
#install.packages("sf") # For working with spatial data
#install.packages("sandwich") # For working with robust standard errors
#install.packages("spdep") # For creating spatial weights matrices
#install.packages("lmtest") # For calculating robust standard errors
#install.packages("interactions") # For examining interaction effects
#install.packages("viridis") # For using the Viridis color scales
#install.packages("ggdist") # For visualizing distributions
#install.packages("MatchIt") # For matching
#install.packages("stargazer") # For exporting regression tables
#install.packages("DescTools") # For calculating McFadden's Adjusted R2
#install.packages("marginaleffects") # For calculating marginal effects
#install.packages("insight") # For calculating robust standard errors for marginal effects
#install.packages("ggtext") # For adding text to ggplot objects
#install.packages("interflex") # For interrogating interaction effects

# Load packages

library(here) # For using relative paths (must be loaded first)
library(ggplot2) # For making graphs and figures
library(tidyverse) # For working with tidy data
library(sf) # For working with spatial data
library(sandwich) # For working with robust standard errors
library(spdep) # For creating spatial weights matrices 
library(lmtest) # For calculating robust standard errors
library(interactions) # For examining interaction effects
library(viridis) # For using the Viridis color scales
library(ggdist) # For visualizing distributions
library(MatchIt) # For matching
library(stargazer) # For For exporting regression tables
library(DescTools) # For calculating McFadden's Adjusted R2
library(marginaleffects) # For calculating marginal effects
library(insight) # For calculating robust standard errors for marginal effects 
library(ggtext) # For adding text to ggplot objects
library(interflex) # For interrogating interaction effects

# Load election dataset

load("df.Rdata")

# Load electoral violence dataset 

load("ev.Rdata")

# Load voting districts shapefile

shapefile <- st_read("shapefile.shp")

#### Data management ####

##### Create electoral violence variables ####

# Merge election dataset with shapefile

df <- shapefile %>%
  rename(Vote.District = Legislativ) %>%
  left_join(df, by = "Vote.District")

# Make electoral violence dataset spatial to enable geo-processing

ev <- as.data.frame(ev) %>%
  st_as_sf(coords = c("Longitude", "Latitude"), crs = 4326, remove = FALSE)

# Create electoral violence variables

ev <- ev %>%
  mutate(
    Electoral.Violence.Events.Opposition = case_when(
      Actor1Side == 1 & EventDirection == 0 ~ 1,
      Actor1Side == 1 & ViolenceInitiator == "0,1" ~ 1,
      TRUE ~ 0
    ),
    Electoral.Violence.Events.Incumbent = case_when(
      Actor1Side == 0 & EventDirection == 0 ~ 1,
      Actor1Side == 0 & ViolenceInitiator == "0,1" ~ 1,
      Actor2Side == 0 & ViolenceInitiator == "0,2" ~ 1,
      TRUE ~ 0
    ),
    Electoral.Violence.Events.Casualties = case_when(
      ParticipantDeaths > 0 | ParticipantInjuries > 0 ~ 1,
      TRUE ~ 0
    ),
    Electoral.Violence.Events.No.Casualties = case_when(
      ParticipantDeaths == 0 & ParticipantInjuries == 0 ~ 1,
      TRUE ~ 0
    ),
    Electoral.Violence.Events.Clear = case_when(
      Clarity == 1 ~ 1,
      TRUE ~ 0
    ),
    Timing = case_when(
      Date <= "2020-10-31" ~ "Pre-election",
      TRUE ~ "Post-election"
    ),
    Electoral.Violence.Severity = ParticipantDeaths + ParticipantInjuries
  )

# Subset datasets to enable geo-processing

ev_opposition <- ev %>% filter(Electoral.Violence.Events.Opposition == 1)

ev_incumbent <- ev %>% filter(Electoral.Violence.Events.Incumbent == 1)

ev_casualties <- ev %>% filter(Electoral.Violence.Events.Casualties == 1)

ev_no_casualties <- ev %>% filter(Electoral.Violence.Events.No.Casualties == 1)

ev_clear <- ev %>% filter(Electoral.Violence.Events.Clear == 1)

ev_pre <- ev %>% filter(Timing == "Pre-election")

ev_post <- ev %>% filter(Timing == "Post-election")

ev_severity <- ev %>% select(Electoral.Violence.Severity)

df_severity <- df %>% select(Vote.District)

ev_severity <- st_join(df_severity, ev_severity)

# Create electoral violence event count variables by counting points in polygon

df <- df %>% 
  mutate(
    Electoral.Violence.Events = lengths(st_intersects(x = df, y = ev)),
    Electoral.Violence.Events.Opposition = lengths(st_intersects(x = df, y = ev_opposition)),
    Electoral.Violence.Events.Incumbent = lengths(st_intersects(x = df, y = ev_incumbent)),
    Electoral.Violence.Events.Casualties = lengths(st_intersects(x = df, y = ev_casualties)),
    Electoral.Violence.Events.Dummy = case_when(Electoral.Violence.Events > 0 ~ 1, TRUE ~ 0),
    Electoral.Violence.Events.No.Casualties = lengths(st_intersects(x = df, y = ev_no_casualties)),
    Electoral.Violence.Events.Clear = lengths(st_intersects(x = df, y = ev_clear )),
    Pre.Electoral.Violence.Events = lengths(st_intersects(x = df, y = ev_pre)),
    Post.Electoral.Violence.Events = lengths(st_intersects(x = df, y = ev_post))
  )

# Sum number of victims by vote district

ev_severity <- ev_severity %>%
  group_by(Vote.District) %>%
  mutate(Electoral.Violence.Severity = sum(Electoral.Violence.Severity)) %>%
  distinct(Vote.District, .keep_all = TRUE)

ev_severity$Electoral.Violence.Severity[is.na(ev_severity$Electoral.Violence.Severity)] <- 0

##### Create spatial lag variables ####

# Identify contiguous voting district neighbors

contig <- poly2nb(df)

# Create a spatial weights matrix (row-standardized)

spcontig <- nb2listw(contig, zero.policy = TRUE)

# Create spatially lagged electoral violence variables

df$Electoral.Violence.Events.Spatial.Lag <- lag.listw(spcontig, df$Electoral.Violence.Events)

##### Create incumbent strength variables ####

df <- df %>%
  mutate(
    RDR.Vote.Share.2010.Sq = RDR.Vote.Share.2010 ^ 2,
    RDR.Margin.2010 = RDR.Vote.Share.2010 - Competitor.Vote.Share.2010,
    RDR.Dominance.2010 = RDR.Vote.Share.2010 * RDR.Margin.2010
  )

##### Remove superfluous dataframes ####

rm("contig", "ev_incumbent", "ev_opposition", "spcontig", "ev_casualties", "ev_clear", "ev_pre", "ev_post", "df_severity", "ev_no_casualties")

#### Descriptive statistics ####

##### Make electoral violence and voter turnout map ####

# Make map

ggplot(data = df) +
  geom_sf(
    aes(
      fill = Voter.Turnout.2021
    ),
    color = "white",
    size = 0.1,
  ) +
  coord_sf(
    xlim = c(-9, -2),
    ylim = c(4, 11),
    expand = FALSE
  ) +
  scale_fill_viridis(
    name = "Voter turnout",
    option = "viridis",
    discrete = FALSE,
    begin = 0.1,
    end = 0.9,
    direction = -1,
    na.value = "white",
    limits = c(0, 1)
  ) +
  geom_count(
    data = ev,
    aes(
      x = Longitude,
      y = Latitude
    ),
    shape = 21,
    color = "black",
    fill = "white",
    alpha = 0.6
  ) +
  scale_size(
    name = "Event count",
    range = c(3, 14)
  ) +
  annotate(
    "text",
    x = -3.55,
    y = 9.1,
    label = "Bouna\nNational\nPark",
    size = 3.5,
    lineheight = 1,
    hjust = "center"
  ) +
  theme_void() +
  theme(
    plot.title = element_text(size = 16, face = "bold", hjust = 0, margin = margin (t = 0, r = 0, b = 10, l = 0)),
    plot.caption = element_text(hjust = 1, size = 8, lineheight = 0.5, margin = margin (t = 20, r = 0, b = 20, l = 0)),
    legend.position = "right",
    plot.subtitle = element_markdown(size = 12, hjust = 0, lineheight = 1.2, margin = margin (t = 0, r = 0, b = 20, l = 0))
  )

ggsave("figure_5.jpg", width = 10, height = 8.9, dpi = 600)

##### Make electoral violence and incumbent strength map ####

# Make map

ggplot(data = df) +
  geom_sf(
    aes(
      fill = RDR.Vote.Share.2010
    ),
    color = "white",
    size = 0.1,
  ) +
  coord_sf(
    xlim = c(-9, -2),
    ylim = c(4, 11),
    expand = FALSE
  ) +
  scale_fill_viridis(
    name = "Incumbent vote share",
    option = "viridis",
    discrete = FALSE,
    begin = 0.1,
    end = 0.9,
    direction = -1,
    na.value = "white",
    limits = c(0, 1)
  ) +
  geom_count(
    data = ev,
    aes(
      x = Longitude,
      y = Latitude
    ),
    shape = 21,
    color = "black",
    fill = "white",
    alpha = 0.6
  ) +
  scale_size(
    name = "Event count",
    range = c(3, 14)
  ) +
  annotate(
    "text",
    x = -3.55,
    y = 9.1,
    label = "Bouna\nNational\nPark",
    size = 3.5,
    lineheight = 1,
    hjust = "center"
  ) +
  theme_void() +
  theme(
    plot.title = element_text(size = 16, face = "bold", hjust = 0, margin = margin (t = 0, r = 0, b = 10, l = 0)),
    plot.caption = element_text(hjust = 1, size = 8, lineheight = 0.5, margin = margin (t = 20, r = 0, b = 20, l = 0)),
    legend.position = "right",
    plot.subtitle = element_markdown(size = 12, hjust = 0, lineheight = 1.2, margin = margin (t = 0, r = 0, b = 20, l = 0))
  )

ggsave("figure_6.jpg", width = 10, height = 8.9, dpi = 600)

##### Make electoral violence and incumbent strength 2021 map ####

# Make map

ggplot(data = df) +
  geom_sf(
    aes(
      fill = RHDP.Vote.Share.2021
    ),
    color = "white",
    size = 0.1,
  ) +
  coord_sf(
    xlim = c(-9, -2),
    ylim = c(4, 11),
    expand = FALSE
  ) +
  scale_fill_viridis(
    name = "Incumbent vote share",
    option = "viridis",
    discrete = FALSE,
    begin = 0.1,
    end = 0.8,
    direction = -1,
    na.value = "white",
    limits = c(0, 1)
  ) +
  geom_count(
    data = ev,
    aes(
      x = Longitude,
      y = Latitude
    ),
    shape = 21,
    color = "black",
    fill = "white",
    alpha = 0.6
  ) +
  scale_size(
    name = "Event count",
    range = c(3, 14)
  ) +
  annotate(
    "text",
    x = -3.55,
    y = 9.1,
    label = "Bouna\nNational\nPark",
    size = 3.5,
    lineheight = 1,
    hjust = "center"
  ) +
  theme_void() +
  theme(
    plot.title = element_text(size = 16, face = "bold", hjust = 0, margin = margin (t = 0, r = 0, b = 10, l = 0)),
    plot.caption = element_text(hjust = 1, size = 8, lineheight = 0.5, margin = margin (t = 20, r = 0, b = 20, l = 0)),
    legend.position = "right",
    plot.subtitle = element_markdown(size = 12, hjust = 0, lineheight = 1.2, margin = margin (t = 0, r = 0, b = 20, l = 0))
  )

ggsave("figure_a3.jpg", width = 10, height = 8.9, dpi = 600)

##### Make timeline of electoral violence events ####

ev %>%
  mutate(
    Events = 1,
    Date = as.Date(Date, format =  "%Y-%m-%d")
  ) %>%
  complete(
    Date = seq.Date(min(as.Date("2020-07-31")), max(as.Date("2021-03-06")), by = "day"),
    fill = list(Events = 0, ParticipantDeaths = 0, ParticipantInjuries = 0)
  ) %>%
  group_by(Date) %>%
  mutate(
    Events = sum(Events),
    Victims = ParticipantDeaths + ParticipantInjuries,
  ) %>%
  distinct(Date, .keep_all = TRUE) %>%
  ggplot() +
  geom_area(
    aes(
      x = Date,
      y = Events
    ),
    fill = "#482878FF",
    alpha = 0.8
  ) +
  geom_vline(xintercept = as.numeric(as.Date("2020-08-06")), linetype = "dashed") +
  annotate(
    "label",
    x = as.Date("2020-08-06"),
    y = 80,
    label = "Ouattara \n announces his \n third-term bid",
    size = 4,
    lineheight = 1,
    hjust = "center",
    color = "black",
    fill = "white"
  ) +
  geom_vline(xintercept = as.numeric(as.Date("2020-09-20")), linetype = "dashed") +
  annotate(
    "label",
    x = as.Date("2020-09-20"),
    y = 30,
    label = "Opposition calls \n for a nationwide \n civil disobedience \n campaign",
    size = 4,
    lineheight = 1,
    hjust = "center",
    color = "black",
    fill = "white"
  ) +
  geom_vline(xintercept = as.numeric(as.Date("2020-10-15")), linetype = "dashed") +
  annotate(
    "label",
    x = as.Date("2020-10-15"),
    y = 50,
    label = "Opposition announces \n an election boycott",
    size = 4,
    lineheight = 1,
    hjust = "center",
    color = "black",
    fill = "white"
  ) +
  geom_vline(xintercept = as.numeric(as.Date("2020-10-31")), linetype = "dashed") +
  annotate(
    "label",
    x = as.Date("2020-10-31"),
    y = 100,
    label = "Presidential \n election",
    size = 4,
    lineheight = 1,
    hjust = "center",
    color = "black",
    fill = "white"
  ) +
  geom_vline(xintercept = as.numeric(as.Date("2021-03-06")), linetype = "dashed") +
  annotate(
    "label",
    x = as.Date("2021-03-06"),
    y = 60,
    label = "Legislative \n election",
    size = 4,
    lineheight = 1,
    hjust = "center",
    color = "black",
    fill = "white"
  ) +
  scale_y_continuous(
    breaks = seq(0, 100, by = 10)
  ) +
  scale_x_date(
    date_breaks = "1 month",
    date_labels = "%B %Y"
  ) +
  labs(
    x = NULL,
    y = "Number of electoral violence events"
  ) +
  theme_bw() +
  theme(
    axis.title.y = element_text(margin = margin (t = 0, r = 10, b = 0, l = 0), size = 16),
    axis.title.x = element_text(margin = margin (t = 10, r = 0, b = 0, l = 0), size = 16),
    axis.text.y = element_text(size = 14),
    axis.text.x = element_text(size = 12)
  )

ggsave("figure_4.jpg", width = 14, height = 8.9, dpi = 600)

# Transform into normal data frame

df <- df %>% as.data.frame

# Add severity variable to data frame

df <- left_join(df, ev_severity, by = "Vote.District")

# Remove severity data frame

rm("ev_severity")

##### Create descriptive statistics table ####

df_descriptive <- df %>% 
  select(
    Voter.Turnout.2021,
    Electoral.Violence.Events,
    Electoral.Violence.Events.Opposition,
    Electoral.Violence.Events.Incumbent,
    Electoral.Violence.Events.Casualties,
    Electoral.Violence.Events.Spatial.Lag,
    RDR.Vote.Share.2010,
    Electoral.Violence.Events.2011,
    Number.of.Seats.2021,
    Voter.Turnout.2016,
    Poverty.Ratio,
    Population.2014.Logged
  )

stargazer(
  df_descriptive,
  covariate.labels = c(
    "Voter turnout",
    "Electoral violence (all)",
    "Opposition violence",
    "Incumbent violence",
    "Severe violence",
    "Electoral violence (spatial lag)",
    "Incumbent strength",
    "Electoral violence (2011)",
    "Number of seats",
    "Voter turnout (2016)",
    "Poverty ratio",
    "Logged population size"
  ),
  title = "Descriptive statistics",
  digits = 2,
  omit.summary.stat = c("p25", "p75"),
  type = "text",
  out = "table_a1",
  median = TRUE
)

rm(df_descriptive)

#### Main analysis ####

##### Model 1: Bivariate regression of electoral violence and voter turnout ####

# Specify model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Events,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

##### Model 2: Multivariate regression of electoral violence and voter turnout ####

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

##### Model 3: Multivariate regression of electoral violence and voter turnout with interaction ####

# Specify model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Calculate predicted values

predictions(
  model3, 
  newdata = datagrid(
    RDR.Vote.Share.2010 = c(0.1, 0.7),
    Electoral.Violence.Events = c(0, 3)
  ),
  vcov = sandwich::vcovHC(model3, type = "HC")
)

# Calculate change in standard deviation

(0.53-0.38)/sd(df$Voter.Turnout.2021)

# Calculate the Johnson-Neyman interval (regions of significance)

sim_slopes(
  model3,
  pred = Electoral.Violence.Events,
  modx = RDR.Vote.Share.2010, 
  robust = "HC",
  centered = "all"
)

# Calculate the share of observations that fall within the Johnson-Neyman interval

length(df$RDR.Vote.Share.2010[df$RDR.Vote.Share.2010 > 0.2])/205

###### Make predicted values plot ####

# Calculate mean +/- standard deviation of incumbent strength

mean(df$RDR.Vote.Share.2010)

mean(df$RDR.Vote.Share.2010) - sd(df$RDR.Vote.Share.2010)

mean(df$RDR.Vote.Share.2010) + sd(df$RDR.Vote.Share.2010)

# Calculate adjusted predictions

predicted3 <- predictions(
  model3, 
  newdata = datagrid(
    RDR.Vote.Share.2010 = c(0.08, 0.67),
    Electoral.Violence.Events = c(0:15)
  ),
  vcov = sandwich::vcovHC(model3, type = "HC")
)

# Plot predicted values

ggplot(data = predicted3) +
  geom_line(aes(x = Electoral.Violence.Events, y = predicted, color = as.factor(RDR.Vote.Share.2010))) +
  geom_ribbon(aes(x = Electoral.Violence.Events, ymin = conf.low, ymax = conf.high, fill = as.factor(RDR.Vote.Share.2010)), alpha = 0.2) +
  scale_color_viridis(
    name = "Incumbent strength",
    labels = c("Low (mean - 1 SD)", "High (mean + 1 SD)"),
    discrete = TRUE,
    begin = 0.1,
    end = 0.9
  ) +
  scale_fill_viridis(discrete = TRUE) +
  scale_y_continuous(
    breaks = seq(0, 1, 0.25),
    minor_breaks = FALSE,
    labels = scales::percent_format(accuracy = 5L),
    limits = c(0, 1)
  ) +
  scale_x_continuous(
    breaks = seq(0, 18, 4),
    minor_breaks = FALSE
  ) +
  guides(fill = "none") +
  labs(
    y = "Predicted voter turnout rate",
    x = "Number of electoral violence events"
  ) +
  theme_bw() +
  theme(
    plot.margin = unit(c(1,1,1,1), "cm"),
    axis.title.y = element_text(margin = margin (t = 0, r = 10, b = 0, l = 0), size = 14),
    axis.title.x = element_text(margin = margin (t = 10, r = 0, b = 0, l = 0), size = 14),
    axis.text.x = element_text(size = 12),
    axis.text.y = element_text(size = 12),
    legend.position = "bottom"
  )

ggsave("figure_7_panel_left.jpg", height = 15, width = 17, units = "cm", dpi = 600)

###### Make marginal effects plot ####

# Calculate marginal effects for different levels of incumbent strength

marginal3 <- plot_cme(
  model3, effect = "Electoral.Violence.Events", 
  condition = "RDR.Vote.Share.2010",
  vcov = sandwich::vcovHC(model3, type = "HC"),
  draw = FALSE
)

# Define transform value for y-scale

coeff <- 0.4

# Make conditional effects plot with super-imposed distribution of incumbent strength

ggplot() +
  geom_histogram(data = df, aes(x = RDR.Vote.Share.2010, y = (..count..) * 0.01), fill = alpha("#482878FF", 0.8)) +
  geom_line(data = marginal3, aes(x = condition1, y = comparison + coeff)) +
  geom_ribbon(data = marginal3, aes(x = condition1, ymin = conf.low + coeff, ymax = conf.high + coeff), fill = "#482878FF", alpha = 0.4) +
  scale_y_continuous(
    breaks = seq(0, 0.8, 0.1),
    labels = seq(-0.4, 0.4, 0.1),
    sec.axis = sec_axis(
      trans = ~. * 100, 
      name = "Number of observations", 
      breaks = seq(0, 50, 10)
    )
  ) +
  scale_x_continuous(breaks = seq(0, 1, 0.2), limits = c(0, 1), labels = scales::percent) +
  geom_hline(yintercept = 0.4, size = 0.5, linetype = 2) +
  geom_vline(xintercept = 0.2, size = 0.5, linetype = 2) +
  labs(
    y = "Marginal effect of electoral violence on turnout",
    x = "Incumbent vote share",
    title = NULL
  ) +
  theme_bw() +
  theme(
    plot.margin = unit(c(1,1,1,1), "cm"),
    axis.title.y = element_text(margin = margin (t = 0, r = 10, b = 0, l = 0), size = 14),
    axis.title.x = element_text(margin = margin (t = 10, r = 0, b = 0, l = 0), size = 14),
    axis.title.y.right = element_text(margin = margin (t = 0, r = 0, b = 0, l = 10), size = 14),
    axis.text.x = element_text(size = 12),
    axis.text.y = element_text(size = 12),
    legend.position = "bottom"
  )

ggsave("figure_7_panel_right.jpg", height = 15, width = 17, units = "cm", dpi = 600)

##### Model 4: Multivariate regression of opposition-initiated and incumbent-initiated electoral violence and voter turnout ####

# Specify model 4

model4 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Opposition * RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Incumbent * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model4, vcov = vcovHC(model4, type = "HC"))

##### Model 5: Multivariate regression of electoral violence resulting in casualties ####

# Specify model 5

model5 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Casualties * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model5, vcov = vcovHC(model5, type = "HC"))

##### Make regression table ####

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))
robust_se4 <- sqrt(diag(vcovHC(model4, type = "HC")))
robust_se5 <- sqrt(diag(vcovHC(model5, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden4 <- format(round(PseudoR2(model4, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden5 <- format(round(PseudoR2(model5, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  model4,
  model5,
  title = "Fractional regression of voter turnout and electoral violence",
  label = "tab:reg",
  align = FALSE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3, robust_se4, robust_se5),
  dep.var.labels = "Voter turnout",
  digits = 2,
  single.row = TRUE,
  omit.table.layout = "ld",
  order = c(1,12,2,13,5,14,3,15,4,6,7,8,9,10,11),
  covariate.labels = c(
    "All violence",
    "All violence x Incumbent strength",
    "Opposition violence",
    "Opposition violence x Incumbent strength",
    "Incumbent violence",
    "Incumbent violence x Incumbent strength",
    "Severe violence",
    "Severe violence x Incumbent strength",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3, mcfadden4, mcfadden5)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_I"
)

#### Additional analyses and robustness tests ####

#### Matching ####

# Create binary electoral violence variable to match on

df <- df %>% mutate(Electoral.Violence.Events.Dummy = case_when(Electoral.Violence.Events > 0 ~ 1, TRUE ~ 0))

# Matching using Coarsened Exact Matching (CEM)

match.it <- matchit(
  Electoral.Violence.Events.Dummy
  ~ RDR.Vote.Share.2010
  + Electoral.Violence.Events.Spatial.Lag,
  data = df,
  method = "cem"
)

# Show matching diagnostics (Table A2)

summary(match.it)

summary(
  match.it, 
  addlvariables = ~ Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df
)

# Create new dataset based on the CEM 

df_matched <- match.data(match.it)

##### Model 1: Bivariate regression of electoral violence and voter turnout ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Events.Dummy,
  data = df_matched,
  family = binomial(link = logit),
  weights = weights
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

##### Model 2: Multivariate regression of electoral violence and voter turnout ####

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Dummy +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df_matched,
  family = binomial(link = logit),
  weights = weights
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

##### Model 3: Multivariate regression of electoral violence and voter turnout with interaction ####

# Specify Model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Dummy * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df_matched,
  family = binomial(link = logit),
  weights = weights
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Calculate predicted values

predictions(
  model3, 
  newdata = datagrid(
    RDR.Vote.Share.2010 = c(0.1, 0.7),
    Electoral.Violence.Events.Dummy = c(0, 1)
  ),
  vcov = sandwich::vcovHC(model3, type = "HC")
)

###### Make marginal effects plot ####

# Calculate marginal effects for different levels of incumbent strength

marginal3 <- plot_cme(
  model3, effect = "Electoral.Violence.Events.Dummy", 
  condition = "RDR.Vote.Share.2010",
  vcov = sandwich::vcovHC(model3, type = "HC"),
  draw = FALSE
)

# Define transform value for y-scale

coeff <- 0.4

# Make conditional effects plot with super-imposed distribution of incumbent strength

ggplot() +
  geom_histogram(data = df_matched, aes(x = RDR.Vote.Share.2010, y = (..count..) * 0.01), fill = alpha("#482878FF", 0.8)) +
  geom_line(data = marginal3, aes(x = condition1, y = comparison + coeff)) +
  geom_ribbon(data = marginal3, aes(x = condition1, ymin = conf.low + coeff, ymax = conf.high + coeff), fill = "#482878FF", alpha = 0.4) +
  scale_y_continuous(
    breaks = seq(0, 0.8, 0.1),
    labels = seq(-0.4, 0.4, 0.1),
    sec.axis = sec_axis(
      trans = ~. * 100, 
      name = "Number of observations", 
      breaks = seq(0, 50, 10)
    )
  ) +
  scale_x_continuous(breaks = seq(0, 1, 0.2), limits = c(0, 1), labels = scales::percent) +
  geom_hline(yintercept = 0.4, size = 0.5, linetype = 2) +
  labs(
    y = "Marginal effect of electoral violence on turnout",
    x = "Incumbent vote share",
    title = NULL
  ) +
  theme_bw() +
  theme(
    plot.margin = unit(c(1,1,1,1), "cm"),
    axis.title.y = element_text(margin = margin (t = 0, r = 10, b = 0, l = 0), size = 14),
    axis.title.x = element_text(margin = margin (t = 10, r = 0, b = 0, l = 0), size = 14),
    axis.title.y.right = element_text(margin = margin (t = 0, r = 0, b = 0, l = 10), size = 14),
    axis.text.x = element_text(size = 12),
    axis.text.y = element_text(size = 12),
    legend.position = "bottom"
  )

ggsave("figure_a5.jpg", height = 15, width = 17, units = "cm", dpi = 600)

##### Make regression table ####

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Fractional regression of voter turnout and electoral violence (matched sample)",
  label = "tab:reg-matched",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence (dummy)",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence (dummy) x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a3"
)

#### Placebo test using competitiveness instead of incumbent strength ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * Competitiveness.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type="HC"))

# Specify Model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * Competitiveness.2010 +
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type="HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  title = "Placebo test",
  label = "tab:reg-placebo",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2),
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Competitiveness",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence x Competitiveness",
    "Electoral violence x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a4"
)

##### Disaggregating the timing of violence ####

df <- df %>% mutate(
  Pre.Election.Dummy = case_when(Pre.Electoral.Violence.Events > 0 ~ 1, TRUE ~ 0),
  Post.Election.Dummy = case_when(Post.Electoral.Violence.Events > 0 ~ 1, TRUE ~ 0)
)

# Specify model 1

model1 <- glm(
  Voter.Turnout.2021 ~
    Pre.Electoral.Violence.Events * RDR.Vote.Share.2010 +
    Post.Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type="HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  title = "Disaggregating electoral violence by timing",
  label = "tab:reg-timing",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "scriptsize",
  single.row = FALSE,
  omit.table.layout = "ld",
  order = c(1,2,4,5,3),
  covariate.labels = c(
    "Pre-electoral violence",
    "Post-electoral violence",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Pre-electoral violence x Incumbent strength",
    "Post-electoral violence x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a5"
)

#### Using a dichotomous independent and moderating variable ####

# Create RDR stronghold variable

df <- df %>% mutate(RDR.Stronghold.2010 = case_when(RDR.Vote.Share.2010 >= 0.5 ~ 1, TRUE ~ 0))

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Events.Dummy,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Dummy +
    RDR.Stronghold.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

# Specify Model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Dummy * RDR.Stronghold.2010 +
    RDR.Stronghold.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit),
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Fractional regression using a dichotomous independent and moderating variable)",
  label = "tab:reg-dummies",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence (dummy)",
    "Incumbent stronghold (dummy)",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence (dummy) x Incumbent stronghold (dummy)"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a6"
)

#### Using a different measure of electoral violence ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Severity,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Severity +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

# Specify Model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Severity * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Using A Different Measure of Electoral Violence",
  label = "tab:reg-severity",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence severity",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence severity x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a7"
)

#### Excluding uncertain electoral violence events ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ Electoral.Violence.Events.Clear,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type="HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Clear +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type="HC"))

# Specify model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events.Clear * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type="HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Excluding uncertain electoral violence events",
  label = "tab:reg-clear",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a8"
)

#### Using alternative measures of incumbent strength ####

# Create incumbent strength variable

df <- df %>%
  mutate(Incumbent.Strength.2010 = RDR.Vote.Share.2010 * (RDR.Vote.Share.2010 / Competitor.Vote.Share.2010))

# Specify model 1

model1 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Margin.2010 +
    RDR.Margin.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type="HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * Incumbent.Strength.2010 +
    Incumbent.Strength.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type="HC"))

# Specify model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RHDP.Vote.Share.2021 +
    RHDP.Vote.Share.2021 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type="HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Using alternative measures of incumbent strength",
  label = "tab:reg-alt",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Incumbent margin of victory (2010)",
    "Incumbent dominance (2010)",
    "Incumbent vote share (2021)",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence x Incumbent margin of victory (2010)",
    "Electoral violence x Incumbent dominance (2010)",
    "Electoral violence x Incumbent vote share (2021)"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a9"
)

#### Excluding voting districts with irregular results ####

# Create variable of invalid ballots

df <- df %>% mutate(Missing.Votes = abs(1 - Sum.of.Vote.Shares.2021))

# Show summary statistics for invalid ballots

summary(df$Missing.Votes)

# Specify model to examine the determinants of invalid ballots

missing.votes <- lm(
  Missing.Votes ~
    Electoral.Violence.Events +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df,
)

# Show results

summary(missing.votes)

# Calculate predicted values

predictions(
  missing.votes, 
  newdata = datagrid(
    Population.2014.Logged = c(7.85, 13.88)
  ),
  vcov = sandwich::vcovHC(model3, type = "HC")
)

# Make regression table

stargazer(
  missing.votes,
  title = "Linear regression of invalid ballots",
  label = "tab:reg-invalid",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  dep.var.labels = "Share of invalid ballots",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  covariate.labels = c(
    "Electoral violence",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size"
  ),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a10"
)

# Identify voting districts with suspected fraud

df <- df %>%
  mutate(
    Fraud = case_when(
      Missing.Votes > 2 * sd(Missing.Votes) ~ 1,
      Sum.of.Vote.Shares.2021 > 1 ~ 1,
      TRUE ~ 0
    )
  )

# Subset data to voting districts without suspected fraud

df.fraud <- df %>% filter(Fraud == 0)

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ Electoral.Violence.Events,
  data = df.fraud,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type="HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df.fraud,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type="HC"))

# Specify model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged,
  data = df.fraud,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type="HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Exluding voting districts with irregular results",
  label = "tab:reg-fraud",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a11"
)

#### Including region-level fixed effects ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Events +
    Region,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged +
    Region,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

# Specify Model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged +
    Region,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Fixed effects fractional regression",
  label = "tab:reg-fixed",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Past voter turnout",
    "Poverty ratio",
    "Logged population size",
    "Electoral violence x Incumbent strength"
  ),
  omit = "Region",
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a12"
)

##### Controlling for voter turnout in 2020 ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Events,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged +
    Voter.Turnout.2020,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

# Specify Model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Electoral.Violence.Events.Spatial.Lag +
    Electoral.Violence.Events.2011 +
    Number.of.Seats.2021 +
    Voter.Turnout.2016 +
    Poverty.Ratio +
    Population.2014.Logged +
    Voter.Turnout.2020,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Controlling for voter turnout in 2020",
  label = "tab:reg-turnout2020",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Incumbent strength",
    "Electoral violence (spatial lag)",
    "Past electoral violence",
    "Number of seats",
    "Voter turnout (2016)",
    "Poverty ratio",
    "Logged population size",
    "Voter turnout (2020)",
    "Electoral violence x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a13"
)

#### Parsimonious models ####

# Specify Model 1

model1 <- glm(
  Voter.Turnout.2021 ~ 
    Electoral.Violence.Events * RDR.Vote.Share.2010,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model1, vcov = vcovHC(model1, type = "HC"))

# Specify model 2

model2 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Voter.Turnout.2016,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model2, vcov = vcovHC(model2, type = "HC"))

# Specify Model 3

model3 <- glm(
  Voter.Turnout.2021 ~
    Electoral.Violence.Events * RDR.Vote.Share.2010 +
    RDR.Vote.Share.2010 +
    Population.2014.Logged,
  data = df,
  family = binomial(link = logit)
)

# Calculate heteroscedasticity-consistent standard errors

coeftest(model3, vcov = vcovHC(model3, type = "HC"))

# Create lists of robust standard errors

robust_se1 <- sqrt(diag(vcovHC(model1, type = "HC")))
robust_se2 <- sqrt(diag(vcovHC(model2, type = "HC")))
robust_se3 <- sqrt(diag(vcovHC(model3, type = "HC")))

# Create lists of McFadden's Adjusted R2

mcfadden1 <- format(round(PseudoR2(model1, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden2 <- format(round(PseudoR2(model2, c("McFaddenAdj")), 2), nsmall = 2)
mcfadden3 <- format(round(PseudoR2(model3, c("McFaddenAdj")), 2), nsmall = 2)

# Make regression table

stargazer(
  model1,
  model2,
  model3,
  title = "Parsimonious models",
  label = "tab:reg-pars",
  align = TRUE, 
  column.sep.width = "5pt",
  no.space = TRUE,
  omit.stat = c("LL", "ser", "f"),
  se = list(robust_se1, robust_se2, robust_se3),
  dep.var.labels = "Voter turnout",
  digits = 2,
  font.size = "footnotesize",
  single.row = FALSE,
  omit.table.layout = "ld",
  covariate.labels = c(
    "Electoral violence",
    "Incumbent strength",
    "Past voter turnout",
    "Logged population size",
    "Electoral violence x Incumbent strength"
  ),
  add.lines = list(c("McFadden's Adjusted R2", mcfadden1, mcfadden2, mcfadden3)),
  notes.append = FALSE,
  star.cutoffs = c(.1, .05, .01),
  type = "text",
  out = "table_a14"
)

#### Make histograms of all variables ####

# Make visualization theme for histograms

histo_theme <- 
  theme(
    plot.margin = unit(c(1,1,1,1), "cm"),
    axis.title.y = element_text(margin = margin (t = 0, r = 10, b = 0, l = 0), size = 22),
    axis.title.x = element_text(margin = margin (t = 10, r = 0, b = 0, l = 0), size = 22),
    axis.text.x = element_text(size = 16),
    axis.text.y = element_text(size = 16),
    legend.position = "bottom"
  )

# RDR vote share

ggplot() +
  geom_histogram(
    data = df,
    aes(x = RDR.Vote.Share.2010),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "RDR vote share 2010",
    title = NULL
  ) +
  histo_theme

ggsave("histo_rdr_vote_share_2010.png", height = 15, width = 22, units = "cm")

# Electoral violence

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Electoral.Violence.Events),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Electoral violence",
    title = NULL
  ) +
  histo_theme

ggsave("histo_electoral_violence.png", height = 15, width = 22, units = "cm")

# Incumbent violence

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Electoral.Violence.Events.Incumbent),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Incumbent violence",
    title = NULL
  ) +
  histo_theme

ggsave("histo_electoral_violence_incumbent.png", height = 15, width = 22, units = "cm")

# Opposition violence

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Electoral.Violence.Events.Opposition),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Opposition violence",
    title = NULL
  ) +
  histo_theme

ggsave("histo_electoral_violence_opposition.png", height = 15, width = 22, units = "cm")

# Electoral violence (spatial lag)

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Electoral.Violence.Events.Spatial.Lag),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Electoral violence (spatial lag)",
    title = NULL
  ) +
  histo_theme

ggsave("histo_electoral_violence_lag.png", height = 15, width = 22, units = "cm")

# Electoral violence (2011)

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Electoral.Violence.Events.2011),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Electoral violence (2011)",
    title = NULL
  ) +
  histo_theme

ggsave("histo_electoral_violence_2011.png", height = 15, width = 22, units = "cm")

# Number of seats

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Number.of.Seats.2021),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Number of seats",
    title = NULL
  ) +
  histo_theme

ggsave("histo_number_of_seats.png", height = 15, width = 22, units = "cm")

# Voter turnout (2016)

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Voter.Turnout.2016),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Voter turnout (2016)",
    title = NULL
  ) +
  histo_theme

ggsave("histo_voter_turnout_2016.png", height = 15, width = 22, units = "cm")

# Voter turnout (2021)

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Voter.Turnout.2021),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Voter turnout (2016)",
    title = NULL
  ) +
  histo_theme

ggsave("histo_voter_turnout.png", height = 15, width = 22, units = "cm")

# Poverty ratio

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Poverty.Ratio),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Poverty Ratio",
    title = NULL
  ) +
  histo_theme

ggsave("histo_poverty_ratio.png", height = 15, width = 22, units = "cm")

# Logged population size

ggplot() +
  geom_histogram(
    data = df,
    aes(x = Population.2014.Logged),
    stat = "bin"
  ) +
  labs(
    y = "Number of observations",
    x = "Logged population size",
    title = NULL
  ) +
  histo_theme

ggsave("histo_population_size.png", height = 15, width = 22, units = "cm")

#### Diagnosing the interaction effect ####

binning <- interflex(
  Y = "Voter.Turnout.2021",
  D = "Electoral.Violence.Events", 
  X = "RDR.Vote.Share.2010", 
  Z = c(
    "Electoral.Violence.Events.Spatial.Lag", 
    "Electoral.Violence.Events.2011",
    "Number.of.Seats.2021",
    "Voter.Turnout.2016",
    "Poverty.Ratio",
    "Population.2014.Logged"
  ), 
  data = df, 
  estimator = "binning", 
  vcov.type = "robust", 
  main = "Marginal Effects",
  ylim = c(-5, 0),
  figure = TRUE,
  nbins = 3
)

plot(
  binning,
  xlab = "Incumbent strength (%)",
  ylab = "Marginal effect of electoral violence on voter turnout",
  file = "figure_a4_panel_upper.jpg"
)

kernel <- interflex(
  Y = "Voter.Turnout.2021",
  D = "Electoral.Violence.Events", 
  X = "RDR.Vote.Share.2010", 
  Z = c(
    "Electoral.Violence.Events.Spatial.Lag", 
    "Electoral.Violence.Events.2011",
    "Number.of.Seats.2021",
    "Voter.Turnout.2016",
    "Poverty.Ratio",
    "Population.2014.Logged"
  ), 
  data = df, 
  nboots = 200,
  estimator = "kernel", 
  vcov.type = "robust", 
  main = "Marginal Effects"
)

plot(
  kernel,
  xlab = "Incumbent strength (%)",
  ylab = "Marginal effect of electoral violence on voter turnout",
  file = "figure_a4_panel_lower.jpg"
)
